* {
	padding:	0;
	margin:		0;
}

body {
	color:			#000000;
	background-color:	#dddddd;

	font-size:	10pt;
	font-family:	Verdana, "Lucida Sans", Arial, Geneva, Helvetica, Helv, "Myriad Web", Syntax, sans-serif;
}

p,ul,ol {
	text-align: justify;
}

h1, h2, h3, h4, h5, h6
{
	font-family: "Trebuchet MS", Verdana, "Lucida Sans", Arial, Geneva, Helvetica, Helv, "Myriad Web", Syntax, sans-serif;
}

h1
{
	color: #454545;
	font-size: 160%;
	font-weight: bold;
}

h2
{
	color: #454545;
	font-size: 140%;
	font-weight: bold;
}

#head #path {
	color: #000000;
	font-weight: bold;
	text-decoration: none;
	font-size: 100%;
	font-family: Verdana, "Lucida Sans", Arial, Geneva, Helvetica, Helv, "Myriad Web", Syntax, sans-serif;
}

a {
	color: inherit;
	text-decoration: inherit;
	font-weight: bold;
}

a img {
	border: 1px solid black;
}

a:link {
	color: #0000FF;
	text-decoration: underline;
}

a:visited {
	color: #000080;
	text-decoration: underline;
}

a:active {
	color: red;
	text-decoration: underline;
}

a:hover {
	color: red;
	text-decoration: underline;
}

#head,
#foot {
	background: white;
	border: 1px solid black;
	margin: 1em;
	padding: 0.5em 1em 0.5em 1em;
}

#mainspacer {
	float:		right;
	margin:		0 1em 1em 0.5em;
	padding-left:	2em;
	border-left:	2px solid #dddddd;
}

#main {
	float:		right;
	background:	white;
	border:		1px solid black;
	padding:	0.5em 1em 0.5em 1em;
}

.thumbs {
	margin:		1em 0.5em 1em 1em;
}

.thumb img {
	width:		22%;
	min-width:	6em;
	vertical-align: top;
	border: 	1px solid black;
	margin: 	0 0.5em 0.5em 0;
}

#head,
#foot {
	clear: both;
}

#main #name {
	float:		left;
}

#index {
	float:		none;
}

#main #index {	
	float:		right;

	color:		#454545;
	font-size:	140%;
	font-weight:	bold;
	font-family: "Trebuchet MS", Verdana, "Lucida Sans", Arial, Geneva, Helvetica, Helv, "Myriad Web", Syntax, sans-serif;
}

#main img {
	display: block;
	clear: both;
	border: none;
	padding-top: 0.5em;
	margin: 0 auto;
}

#main p + p {
	margin: 1ex 0 0 0;
}

#main #byline,
#main #location {
	font-style:	italic;
	font-size:	80%;
}

#main #location {
	margin-top:	0;
}

#main #exif,
#main #iptc {
	color:		#454545;
}

#foot {
	color: black;
	font-family: Verdana, "Lucida Sans", Arial, Geneva, Helvetica, Helv, "Myriad Web", Syntax, sans-serif;
	text-align: center;
}

#foot #copyright {
	float: left;
}

#foot #date {
	
	float: right;
}

#foot #hack {
	clear: both;
}
