body {
	background-color: #dddddd;
}

p,ul,ol {
	color: black;
	font-size: 80%;
	font-family: Verdana, "Lucida Sans", Arial, Geneva, Helvetica, Helv, "Myriad Web", Syntax, sans-serif;
	text-align: justify;
}

h1, h2, h3, h4, h5, h6, big
{
	font-family: "Trebuchet MS", Verdana, "Lucida Sans", Arial, Geneva, Helvetica, Helv, "Myriad Web", Syntax, sans-serif;
}

big
{
	color: #454545;
	font-size: 130%;
	font-weight: bold;
}

h1
{
	color: #454545;
	font-size: 130%;
	font-weight: bold;
	padding-bottom: 0px;
}

h2
{
	color: #707070;
	font-size: 120%;
	font-weight: normal;
	border: 1px solid #cccccc;
	border-width: 0px 0px 1px 0px;
	padding-bottom: 0px;
}		

h3
{
	color: #707070;
	font-size: 110%;
	font-weight: normal;
	padding-bottom: 0px;
}				

.right {
	text-align: right;
}

.left {
	text-align: left;
}

.center {
	text-align: center;
}

.nav {
	color: #000000;
	font-weight: bold;
	text-decoration: none;
	font-size: 80%;
	font-family: Verdana, "Lucida Sans", Arial, Geneva, Helvetica, Helv, "Myriad Web", Syntax, sans-serif;
}

.title {
	color: #000000;
	font-weight: bold;
	font-style: italic;
	text-decoration: none;
	font-size: 130%;
	font-family: Verdana, "Lucida Sans", Arial, Geneva, Helvetica, Helv, "Myriad Web", Syntax, sans-serif;
}

.boxtitle {
        color: #000000;
        font-weight: bold;
        font-style: italic;
        text-decoration: none;
        font-size: 105%;
        font-family: Verdana, "Lucida Sans", Arial, Geneva, Helvetica, Helv, "Myriad Web", Syntax, sans-serif;
}
						

.box {
	background-color: #eeeeee
}

.boxhead {
	background-color: #aaaaaa
}

.small {
	color: #000000;
	font-size: 60%;
	font-family: Verdana, "Lucida Sans", Arial, Geneva, Helvetica, Helv, "Myriad Web", Syntax, sans-serif;
}

.footer {
	color: #555555;
	font-size: 60%;
	font-family: Verdana, "Lucida Sans", Arial, Geneva, Helvetica, Helv, "Myriad Web", Syntax, sans-serif;
	text-align: center;
}

a {
	color: black;
	font-weight: bold;
	text-decoration: none;
}

a:link {
	text-decoration: none;
}

a:visited {
	text-decoration: none;
}

a:active {
	text-decoration: none;
}

a:hover {
	color: #ff3300;
	text-decoration: underline;
}

div.pic h1.headline {
	margin-top:	0px;
	margin-bottom:	2px;
}

div.pic h1.headline span.name {
	float:		left;
}

div.pic h1.headline span.index {
	float:		right;
}

div.pic p.pic {
	margin-top:	2px;
	margin-bottom:	2px;
}

div.pic p.caption {
	margin-top:	2px;
}

p.byline,
p.location {
	font-style:	italic;
	font-size:	67%;
}

p.byline {
	margin-bottom:	0pt;
}

p.location {
	margin-top:	0pt;
}

p.exif,
p.iptc {
	color:		#454545;
}
